summaryrefslogtreecommitdiffstats
path: root/kio/kfile/knotifydialog.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
commitb19ddece21e102b8e4b292037ca7578f60b128fe (patch)
tree6572ca25aba80849cdfa7578bbbc9121d23afbc3 /kio/kfile/knotifydialog.h
parente729c6d549f12e27b358a1dad04ff254c033ac71 (diff)
downloadtdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.tar.gz
tdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'kio/kfile/knotifydialog.h')
-rw-r--r--kio/kfile/knotifydialog.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kio/kfile/knotifydialog.h b/kio/kfile/knotifydialog.h
index 2adb2b15a..1f758a01b 100644
--- a/kio/kfile/knotifydialog.h
+++ b/kio/kfile/knotifydialog.h
@@ -63,14 +63,14 @@ public:
* @param parent The parent widget for the dialog
* @param name The widget name
* @param modal If true, this will be a modal dialog, otherwise non-modal.
* @param aboutData A pointer to a KAboutData object. KAboutData::appName()
* will be used to find the KNotify events (in the eventsrc file).
* Set this to 0L if you want to add all events yourself with
* addApplicationEvents().
*/
KNotifyDialog( TQWidget *parent = 0, const char *name = 0,
bool modal = true,
- const KAboutData *aboutData =
+ const TDEAboutData *aboutData =
KGlobal::instance()->aboutData() );
/**
* Destroys the KNotifyDialog
@@ -82,13 +82,13 @@ public:
*
* @param parent The parent widget for the dialog
* @param name The widget name
* @param aboutData A pointer to a KAboutData object. KAboutData::appName()
* will be used to find the KNotify events (in the eventsrc file).
* @see exec for the return values.
* @return The value of TQDialog::exec()
*/
static int configure( TQWidget *parent = 0, const char *name = 0,
- const KAboutData *aboutData = KGlobal::instance()->aboutData() );
+ const TDEAboutData *aboutData = KGlobal::instance()->aboutData() );
/**
* With this method, you can add the KNotify events of one eventsrc
@@ -96,7 +96,7 @@ public:
* KNotifyDialog can handle events for multiple applications (i.e. eventsrc files).
* Successive calls with a different @p appName will add them.
* @param appName The application's name, i.e. the name passed to the
* TDEApplication constructor or KAboutData.
* @see clearApplicationEvents()
*/
virtual void addApplicationEvents( const char *appName );
@@ -63,14 +63,14 @@ public:
* @param name The widget name
* @param modal If true, this will be a modal dialog, otherwise non-modal.
- * @param aboutData A pointer to a KAboutData object. KAboutData::appName()
+ * @param aboutData A pointer to a TDEAboutData object. TDEAboutData::appName()
* will be used to find the KNotify events (in the eventsrc file).
* Set this to 0L if you want to add all events yourself with
@@ -82,13 +82,13 @@ public:
* @param parent The parent widget for the dialog
* @param name The widget name
- * @param aboutData A pointer to a KAboutData object. KAboutData::appName()
+ * @param aboutData A pointer to a TDEAboutData object. TDEAboutData::appName()
* will be used to find the KNotify events (in the eventsrc file).
* @see exec for the return values.
@@ -96,7 +96,7 @@ public:
* Successive calls with a different @p appName will add them.
* @param appName The application's name, i.e. the name passed to the
- * TDEApplication constructor or KAboutData.
+ * TDEApplication constructor or TDEAboutData.
* @see clearApplicationEvents()
*/